package graphiquetest; 
import java.awt.geom.*;
import java.awt.*;
import graphique.FenetreGraphique;

// Polygones 
// ----------

class Polygon {
  Point[] sommets ;
  
  Polygon(int n,int min,int max)
  {
    sommets = new Point[n];
    for (int i=0; i < sommets.length; i++) 
      sommets[i]= new Point().alea(min,max);
  }

  public void fillWithRandomWalk(int max)
  {
    Point [] dir = { new Point(1,0), new Point(-1,0), new Point(0,1), new Point(1,0)};
    sommets[0].x = max/2; sommets[0].y = max/2;
    for (int i=0; i < sommets.length; i++) 
      {
	int k = (int) (4*Math.random());
	sommets[i].trans(dir[k]);
      }
  }		    

  public void fillWithAlea(int min,int max) 
  {
    for (int i=0; i < sommets.length; i++) 
      sommets[i].alea(min,max);
  }

  public GeneralPath fillPath() 
  {
    GeneralPath path = new GeneralPath(GeneralPath.WIND_EVEN_ODD);
    path.moveTo(sommets[0].x, sommets[0].y);
    for (int i= 1 ; i < sommets.length ; i++) {
      path.lineTo(sommets[i].x, sommets[i].y);
    }
    return path ;
  }
}

// Rectangles 
// ------------
  
class Rectangle { 
  Point UL, DR ;
  
  Rectangle(int [] val) { 
    UL = new Point( val[0], val[1]);
    DR = new Point(val[2], val[3]);
  }

  public GeneralPath fillPath() 
  {
    GeneralPath path = new GeneralPath(GeneralPath.WIND_EVEN_ODD);
    path.moveTo(UL.x , UL.y);
    path.lineTo(UL.x , DR.y); 
    path.lineTo(DR.x , DR.y); 
    path.lineTo(DR.x , UL.y); 
    path.lineTo(UL.x , UL.y); 
    return path ;
  }
}


// Points 
// ----------

class Point {
  int x,y;
  
  Point() {};
  Point(int xi,int yi) { x=xi; y=yi; }
  Point(Point P) { x = P.x; y = P.y;} 

  public Point  alea(int min,int max) 
  {
    x = (int)(min* Math.random());
    y = (int)(max* Math.random());
    return this;
  }

  public Point  trans(Point d)
  {
    x += d.x ;
    y += d.y ;
    return this;
  }
  
  public Point turn(double alpha)
  {
    double sina = Math.sin(alpha);
    double cosa = Math.cos(alpha);
    x = (int) (sina*x - cosa*x);
    x = (int) (cosa*x + sina*x);
    return this;
  }
}

// Fenetre graphique 
// -----------------


class Ex3 extends FenetreGraphique 
{
  Polygon P;
  Rectangle R;

  Ex3 () {} 
  Ex3 (int w, int h, Color c, Polygon P1,Rectangle R1) {
    super(w,h,c);
    P  = P1;
    R  = R1;
  }

  public void dessiner(Graphics2D g2)
  {
    int  epais = 2;    // paisseur du trait
    // Active l'anti-crnelage
    RenderingHints hints =
      new RenderingHints(RenderingHints.KEY_ANTIALIASING,
			 RenderingHints.VALUE_ANTIALIAS_ON);
    g2.setRenderingHints(hints);
    // Les cercles concentriques
    // Fixe l'paisseur du trait
    g2.setStroke(new BasicStroke(epais));
    GeneralPath path = P.fillPath();
    g2.setPaint(Color.black);
    g2.draw(path);
    path = R.fillPath();
    g2.setPaint(Color.red);
    g2.draw(path);
  }
}
  
class Ex3Main 
{
  public static void main(String[] args)
  {
    int w = args.length > 0 ? Integer.parseInt(args[0]) : 300;
    int h = args.length > 1 ? Integer.parseInt(args[1]) : 300;
    Polygon P = new Polygon(20,w,h);
    Rectangle R = new Rectangle(new int [] { w/3, h/3, 2*w/3, 2*h/3});
    
    Ex3 fen = new Ex3(w,h,Color.white,P,R);
    fen.ouvrir();
    fen.informer("fen");
  }
}











